Module event

Module event 

Events on GitHub

The GitHub integration enables the automatons framework to interact with webhook sevents on GitHub. These events are modelled as strongly-typed data types in this module, and each model maps to a webhook event with its payload.

Structs

CheckRunEvent
Check run event

Enums

CheckRunAction
Check run action
GitHubEvent
Event on GitHub